#ifndef __PELEMENT_IMPL_H__
#define __PELEMENT_IMPL_H__

#include "PElement.h"

///constructeur de PElement
template <class T>
PElement<T>::PElement(){
	p_prev = NULL;
	p_next = NULL;
}

///constructeur de PElement
/**	@param prev : pointeur vers l'élément précédent
 * 	@param next : pointeur vers l'élément suivant
*/
template <class T>
PElement<T>::PElement(PElement<T>* prev, PElement<T>* next){
	p_prev = prev;
	p_next = next;
}

///constructeur de PElement
/**	@param prev : pointeur vers l'élément précédent
 * 	@param next : pointeur vers l'élément suivant
 * 	@param data : donnée que doit contenir le PElement
*/
template <class T>
PElement<T>::PElement(PElement<T>* prev, PElement<T>* next, const T & data){
	p_prev = prev;
	p_next = next;
	p_data = data;
}

///destructeur de PElement
template <class T>
PElement<T>::~PElement(){}



#endif
